<?php

namespace Ecomerciar\Enviopack;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Helper
{

    private $order, $logger;

    public function __construct($order = '')
    {
        $this->order = $order;
        $this->logger = wc_get_logger();
    }

    public function get_comments()
    {
        if (!$this->order) {
            return false;
        }
        return $this->order->get_customer_note();
    }

    public function get_customer()
    {
        if (!$this->order) {
            return false;
        }
        return array(
            'name' => ($this->order->has_shipping_address() ? $this->order->get_shipping_first_name() : $this->order->get_billing_first_name()),
            'last_name' => ($this->order->has_shipping_address() ? $this->order->get_shipping_last_name() : $this->order->get_billing_last_name()),
            'email' => $this->order->get_billing_email(),
            'phone' => $this->order->get_billing_phone()
        );
    }

    public function get_state_center($province_id = '')
    {
        if (!$province_id) {
            return false;
        }
        switch ($province_id) {
            case 'AG':
                $coords = [21.888268197765296, -102.28747901537477];
                break;
            case 'BC':
                $coords = [30.595831188132337, -115.31396531422499];
                break;
            case 'BS':
                $coords = [25.438774175255823, -111.53044432552514];
                break;
            case 'CM':
                $coords = [19.83508961186264, -90.51615020124127];
                break;
            case 'CS':
                $coords = [16.588917631121475, -92.51980137456138];
                break;
            case 'CH':
                $coords = [28.63382215725349, -106.05978299569027];
                break;
            case 'CX':
            case 'DF':
                $coords = [19.424004333249226, -99.15275853675003];
                break;
            case 'CO':
                $coords = [27.512805365832225, -101.87125444168296];
                break;
            case 'CL':
                $coords = [19.24162457886591, -103.72500351242122];
                break;
            case 'DG':
                $coords = [24.934279258070486, -104.73420943720815];
                break;
            case 'GT':
                $coords = [21.01693481093855, -101.25740825524448];
                break;
            case 'GR':
                $coords = [17.63080866510436, -99.79746878190149];
                break;
            case 'HG':
                $coords = [20.415366946773396, -98.98358488214843];
                break;
            case 'JC':
                $coords = [20.6668513027834, -103.35456126654917];
                break;
            case 'MX':
                $coords = [19.83508961186264, -90.51615020124127];
                break;
            case 'MI':
                $coords = [19.47144001361073, -101.68424116732122];
                break;
            case 'MO':
                $coords = [18.7937049176328, -99.07400428603107];
                break;
            case 'NA':
                $coords = [21.915022865388746, -104.7926254661335];
                break;
            case 'NL':
                $coords = [26.57917900796183, -99.99579547131692];
                break;
            case 'OA':
                $coords = [16.847806680136298, -96.69678611935828];
                break;
            case 'PU':
                $coords = [19.036788567851993, -98.20429760638865];
                break;
            case 'QT':
                $coords = [20.606017167167998, -100.41056330096895];
                break;
            case 'QR':
                $coords = [19.381913705290415, -88.18752687988106];
                break;
            case 'SL':
                $coords = [22.538084820400716, -100.55893114165106];
                break;
            case 'SI':
                $coords = [25.15668896074765, -107.50077802607076];
                break;
            case 'SO':
                $coords = [30.295549221182828, -110.36028758947491];
                break;
            case 'TB':
                $coords = [18.289949173564533, -92.47349974364036];
                break;
            case 'TM':
                $coords = [24.270482615314016, -98.66307762694741];
                break;
            case 'TL':
                $coords = [19.30964706992696, -98.22583009723463];
                break;
            case 'VE':
                $coords = [19.176249830326363, -96.13526835698929];
                break;
            case 'YU':
                $coords = [20.90061620217757, -89.09857587776054];
                break;
            case 'ZA':
                $coords = [23.34802237692231, -102.88429905294542];
                break;
        }
        return $coords;
    }

    public function get_province_name($province_id = '')
    {
        switch ($province_id) {
            case 'AG':
                $zone = 'Aguascalientes';
                break;
            case 'BC':
                $zone = 'Baja California';
                break;
            case 'BS':
                $zone = 'Baja California Sur';
                break;
            case 'CM':
                $zone = 'Campeche';
                break;
            case 'CS':
                $zone = 'Chiapas';
                break;
            case 'CH':
                $zone = 'Chihuahua';
                break;
            case 'CX':
            case 'DF':
                $zone = 'Ciudad de México';
                break;
            case 'CO':
                $zone = 'Coahuila';
                break;
            case 'CL':
                $zone = 'Colima';
                break;
            case 'DG':
                $zone = 'Durango';
                break;
            case 'GT':
                $zone = 'Guanajuato';
                break;
            case 'GR':
                $zone = 'Guerrero';
                break;
            case 'HG':
                $zone = 'Hidalgo';
                break;
            case 'JC':
                $zone = 'Jalisco';
                break;
            case 'MX':
                $zone = 'México';
                break;
            case 'MI':
                $zone = 'Michoacán';
                break;
            case 'MO':
                $zone = 'Morelos';
                break;
            case 'NA':
                $zone = 'Nayarit';
                break;
            case 'NL':
                $zone = 'Nuevo León';
                break;
            case 'OA':
                $zone = 'Oaxaca';
                break;
            case 'PU':
                $zone = 'Puebla';
                break;
            case 'QT':
                $zone = 'Querétaro';
                break;
            case 'QR':
                $zone = 'Quintana Roo';
                break;
            case 'SL':
                $zone = 'San Luis Potosí';
                break;
            case 'SI':
                $zone = 'Sinaloa';
                break;
            case 'SO':
                $zone = 'Sonora';
                break;
            case 'TB':
                $zone = 'Tabasco';
                break;
            case 'TM':
                $zone = 'Tamaulipas';
                break;
            case 'TL':
                $zone = 'Tlaxcala';
                break;
            case 'VE':
                $zone = 'Veracruz';
                break;
            case 'YU':
                $zone = 'Yucatán';
                break;
            case 'ZA':
                $zone = 'Zacatecas';
                break;
        }
        return $zone;
    }

    public function get_zones_names_for_shipping_zone()
    {
        $zones = array();
        $zones[] = array('code' => 'MX:AG', 'type' => 'state');
        $zones[] = array('code' => 'MX:BC', 'type' => 'state');
        $zones[] = array('code' => 'MX:BS', 'type' => 'state');
        $zones[] = array('code' => 'MX:CM', 'type' => 'state');
        $zones[] = array('code' => 'MX:CS', 'type' => 'state');
        $zones[] = array('code' => 'MX:CH', 'type' => 'state');
        $zones[] = array('code' => 'MX:CX', 'type' => 'state');
        $zones[] = array('code' => 'MX:DF', 'type' => 'state');
        $zones[] = array('code' => 'MX:CO', 'type' => 'state');
        $zones[] = array('code' => 'MX:CL', 'type' => 'state');
        $zones[] = array('code' => 'MX:DG', 'type' => 'state');
        $zones[] = array('code' => 'MX:GT', 'type' => 'state');
        $zones[] = array('code' => 'MX:GR', 'type' => 'state');
        $zones[] = array('code' => 'MX:HG', 'type' => 'state');
        $zones[] = array('code' => 'MX:JC', 'type' => 'state');
        $zones[] = array('code' => 'MX:MX', 'type' => 'state');
        $zones[] = array('code' => 'MX:MI', 'type' => 'state');
        $zones[] = array('code' => 'MX:MO', 'type' => 'state');
        $zones[] = array('code' => 'MX:NA', 'type' => 'state');
        $zones[] = array('code' => 'MX:NL', 'type' => 'state');
        $zones[] = array('code' => 'MX:OA', 'type' => 'state');
        $zones[] = array('code' => 'MX:PU', 'type' => 'state');
        $zones[] = array('code' => 'MX:QT', 'type' => 'state');
        $zones[] = array('code' => 'MX:QR', 'type' => 'state');
        $zones[] = array('code' => 'MX:SL', 'type' => 'state');
        $zones[] = array('code' => 'MX:SI', 'type' => 'state');
        $zones[] = array('code' => 'MX:SO', 'type' => 'state');
        $zones[] = array('code' => 'MX:TB', 'type' => 'state');
        $zones[] = array('code' => 'MX:TM', 'type' => 'state');
        $zones[] = array('code' => 'MX:TL', 'type' => 'state');
        $zones[] = array('code' => 'MX:VE', 'type' => 'state');
        $zones[] = array('code' => 'MX:YU', 'type' => 'state');
        $zones[] = array('code' => 'MX:ZA', 'type' => 'state');
        return $zones;
    }

    public function get_street()
    {
        if (!$this->order) {
            return false;
        }
        if ($this->order->has_shipping_address()) {
            $address = $this->order->get_shipping_address_1();
        } else {
            $address = $this->order->get_billing_address_1();
        }

        $address_array = explode(" ", $address);
        $address = '';
        foreach ($address_array as $key => $value_of_array) {
            if ($key === 0) {
                $address .= $value_of_array;
            } else {
                if (is_numeric($value_of_array)) {
                    break;
                }
                $address .= ' ' . $value_of_array;
            }
        }
        return $address;
    }

    public function get_province_id()
    {
        if (!$this->order) {
            return false;
        }
        if ($this->order->has_shipping_address()) {
            $province = $this->order->get_shipping_state();
        } else {
            $province = $this->order->get_billing_state();
        }
        return $province;
    }

    public function get_postal_code()
    {
        if (!$this->order) {
            return false;
        }
        if ($this->order->has_shipping_address()) {
            return $this->order->get_shipping_postcode();
        }
        return $this->order->get_billing_postcode();
    }

    private function set_shipping_products_info($products)
    {
        $products['shipping_info']['total_weight'] = 0;
        $products['shipping_info']['products_details_1'] = '';
        $dimensions = array();
        $peso = 0;
        foreach ($products['products'] as $index => $product) {
            $peso += $product['peso'];
            $dimensions[] = array(
                'alto' => $product['alto'],
                'ancho' => $product['ancho'],
                'largo' => $product['largo']
            );
        }
        $products['shipping_info']['total_weight'] += $peso;
        $products['shipping_info']['products_details_1'] = self::get_package_estimated_size($dimensions);
        if (!$products['shipping_info']['products_details_1']) return false;
        return $products;
    }

    private function get_new_product($product_id)
    {
        $product = wc_get_product($product_id);
        if (!$product) {
            return false;
        }
        if (!$product->is_virtual() && (empty($product->get_height()) || empty($product->get_length()) || empty($product->get_width()) || !$product->has_weight())) {
            return false;
        }
        $new_product = array(
            'alto' => ($product->get_height() ? wc_get_dimension($product->get_height(), 'cm') : '0'),
            'ancho' => ($product->get_width() ? wc_get_dimension($product->get_width(), 'cm') : '0'),
            'largo' => ($product->get_length() ? wc_get_dimension($product->get_length(), 'cm') : '0'),
            'peso' => ($product->has_weight() ? wc_get_weight($product->get_weight(), 'kg') : '0'),
            'id' => $product_id,
            'virtual' => $product->is_virtual()
        );
        return $new_product;
    }

    public function get_items_from_cart()
    {
        $products = array(
            'products' => array(),
            'shipping_info' => array()
        );
        $items = WC()->cart->get_cart();
        foreach ($items as $item) {
            $product_id = $item['data']->get_id();
            $new_product = $this->get_new_product($product_id);
            if (!$new_product) {
                $this->logger->error('Enviopack Helper -> Error obteniendo productos del carrito, producto con malas dimensiones - ID: ' . $product_id, ECOM_LOGGER_CONTEXT);
                return false;
            }
            for ($i = 0; $i < $item['quantity']; $i++) {
                if (!$new_product['virtual']) {
                    array_push($products['products'], $new_product);
                }
            }
        }
        $products = $this->set_shipping_products_info($products);
        if (!$products) {
            $this->logger->error('Enviopack Helper -> Error obteniendo productos del carrito, productos con malas dimensiones/peso', ECOM_LOGGER_CONTEXT);
            return false;
        }
        return $products;
    }

    public function get_items_from_order($order)
    {
        $products = array(
            'products' => array(),
            'shipping_info' => array()
        );
        $items = $order->get_items();
        foreach ($items as $item) {
            $product_id = $item->get_variation_id();
            if (!$product_id)
                $product_id = $item->get_product_id();
            $new_product = $this->get_new_product($product_id);
            if (!$new_product) {
                $this->logger->error('Enviopack Helper -> Error obteniendo productos de la orden, producto con malas dimensiones - ID: ' . $product_id, ECOM_LOGGER_CONTEXT);
                return false;
            }
            for ($i = 0; $i < $item->get_quantity(); $i++) {
                array_push($products['products'], $new_product);
            }
        }
        $products = $this->set_shipping_products_info($products);
        if (!$products) {
            $this->logger->error('Enviopack Helper -> Error obteniendo productos de la orden, productos con malas dimensiones/peso', ECOM_LOGGER_CONTEXT);
            return false;
        }
        return $products;
    }

    public function get_street_number()
    {
        if (!$this->order) {
            return false;
        }
        if ($this->order->has_shipping_address()) {
            $address = $this->order->get_shipping_address_1();
        } else {
            $address = $this->order->get_billing_address_1();
        }

        $number = '';
        $address_array = array_reverse(explode(" ", $address));
        foreach ($address_array as $value_of_array) {
            if (is_numeric($value_of_array)) {
                $number = $value_of_array;
                break;
            }
        }

        if (!$number) {
            if ($this->order->has_shipping_address()) {
                $address = $this->order->get_shipping_address_2();
            } else {
                $address = $this->order->get_billing_address_2();
            }
            if (is_numeric($address)) {
                $number = $address;
            }
        }

        return $number;
    }

    public static function get_package_estimated_size($dimensiones)
    {
        $estimation_method = get_option('enviopack_packaging_mode');
        if ($estimation_method === 'sum-package') {
            return self::sum_dim_estimation($dimensiones);
        } else if ($estimation_method === 'max-package') {
            return self::max_dim_estimation($dimensiones);
        } else if ($estimation_method === 'default-package') {
            return self::default_package_estimation();
        } else {
            return 0;
        }
    }

    public static function sum_dim_estimation($dimensiones)
    {
        // Ordeno las dimensiones de los productos para facilitar las comparaciones
        foreach ($dimensiones as &$product_dimensions) {
            sort($product_dimensions);
        }
        // Ordeno los paquetes por tamaño
        array_multisort($dimensiones);

        //- Si el pedido o checkout tiene un solo producto y una sola unidad se crea el paquete con esas dimensiones.
        if (count($dimensiones) == 1) {
            $paquete = implode('x', $dimensiones[0]);
        } else {
            $all_equal_size = true;
            for ($i = 0; $i < count($dimensiones) - 1; $i++) {
                if ($dimensiones[$i] != $dimensiones[$i + 1]) {
                    $all_equal_size = false;
                }
            }

            if ($all_equal_size) {
                //- Si el pedido o checkout tiene un solo producto y 2 unidades se crea el paquete con esas dimensiones. Se calcula 2alto x ancho x largo, donde 2 es la cantidad de productos iguales. En este caso seria bueno no siempre multiplicar la cantidad por el alto sino por la dimension mas chica de las 3: alto o ancho o largo.
                $paquete = ($dimensiones[0][0] * count($dimensiones)) . 'x' . $dimensiones[0][1] . 'x' . $dimensiones[0][2];
            } else {
                //- Si el pedido o checkout tiene varios productos distintos, saco el volumen total y estimo un paquete con forma de cubo. Ej. (20x10x30) + (10x5x30) = 7000cm3 = 24x24x24
                $volumen = 0;
                foreach ($dimensiones as $producto_dimension) {
                    $volumen += $producto_dimension[0] * $producto_dimension[1] * $producto_dimension[2];
                }

                $cube_size = ceil(pow($volumen, 1 / 3));
                $paquete = $cube_size . 'x' . $cube_size . 'x' . $cube_size;
            }
        }

        return $paquete;
    }

    public static function max_dim_estimation($dimensiones)
    {
        // El paquete se arma estimando sus dimensiones en base a las dimension mas alta de cada producto (aun cuando sean muchos productos) Ej: 10x10x20 y 20x5x30. = 20x10x30
        $all_dimensions = array();
        foreach ($dimensiones as $producto_dimension) {
            foreach ($producto_dimension as $dimension_name => $value) {
                $all_dimensions[] = $value;
            }
        }
        rsort($all_dimensions);
        return $all_dimensions[0] . 'x' . $all_dimensions[1] . 'x' . $all_dimensions[2];
    }

    public static function default_package_estimation()
    {
        $ep = new Enviopack;
        $default_package = $ep->get_default_package();
        if (!empty($default_package)) {
            // Alto x ancho x largo
            return $default_package['alto'] . 'x' . $default_package['ancho'] . 'x' . $default_package['largo'];
        } else {
            return false;
        }
    }

    public static function get_address($order)
    {
        if ($order->get_shipping_address_1()) {
            $shipping_line_1 = $order->get_shipping_address_1();
            $shipping_line_2 = $order->get_shipping_address_2();
        } else {
            $shipping_line_1 = $order->get_billing_address_1();
            $shipping_line_2 = $order->get_billing_address_2();
        }

        $street_name = $street_number = $floor = $apartment = "";

        if (!empty($shipping_line_2)) {
            //there is something in the second line. Let's find out what
            $fl_apt_array = self::get_floor_and_apt($shipping_line_2);
            $floor = $fl_apt_array[0];
            $apartment = $fl_apt_array[1];
        }
    
        //Now let's work on the first line
        preg_match('/(^\d*[\D]*)(\d+)(.*)/i', $shipping_line_1, $res);
        $line1 = $res;

        if ((isset($line1[1]) && !empty($line1[1]) && $line1[1] !== " ") && !empty($line1)) {
            //everything's fine. Go ahead
            if (empty($line1[3]) || $line1[3] === " ") {
                //the user just wrote the street name and number, as he should
                $street_name = trim($line1[1]);
                $street_number = trim($line1[2]);
                unset($line1[3]);
            } else {
                //there is something extra in the first line. We'll save it in case it's important
                $street_name = trim($line1[1]);
                $street_number = trim($line1[2]);
                $shipping_line_2 = trim($line1[3]);

                if (empty($floor) && empty($apartment)) {
                    //if we don't have either the floor or the apartment, they should be in our new $shipping_line_2
                    $fl_apt_array = self::get_floor_and_apt($shipping_line_2);
                    $floor = $fl_apt_array[0];
                    $apartment = $fl_apt_array[1];

                } elseif (empty($apartment)) {
                    //we've already have the floor. We just need the apartment
                    $apartment = trim($line1[3]);
                } else {
                    //we've got the apartment, so let's just save the floor
                    $floor = trim($line1[3]);
                }
            }
        } else {
            //the user didn't write the street number. Maybe it's in the second line
            //given the fact that there is no street number in the fist line, we'll asume it's just the street name
            $street_name = $shipping_line_1;

            if (!empty($floor) && !empty($apartment)) {
                //we are in a pickle. It's a risky move, but we'll move everything one step up
                $street_number = $floor;
                $floor = $apartment;
                $apartment = "";
            } elseif (!empty($floor) && empty($apartment)) {
                //it seems the user wrote only the street number in the second line. Let's move it up
                $street_number = $floor;
                $floor = "";
            } elseif (empty($floor) && !empty($apartment)) {
                //I don't think there's a chance of this even happening, but let's write it to be safe
                $street_number = $apartment;
                $apartment = "";
            }
        }

        if (!preg_match('/^ ?\d+ ?$/', $street_number, $res)) {
            //the street number it's not an actual number. We'll move it to street
            $street_name .= " " . $street_number;
            $street_number = "";
        }

        return array('street' => $street_name, 'number' => $street_number, 'floor' => $floor, 'apartment' => $apartment);
    }

    public static function get_floor_and_apt($fl_apt)
    {
        $street_name = $street_number = $floor = $apartment = "";

        //firts we'll asume the user did things right. Something like "piso 24, depto. 5h"
        preg_match('/(piso|p|p.) ?(\w+),? ?(departamento|depto|dept|dpto|dpt|dpt.º|depto.|dept.|dpto.|dpt.|apartamento|apto|apt|apto.|apt.) ?(\w+)/i', $fl_apt, $res);
        $line2 = $res;

        if (!empty($line2)) {
            //everything was written great. Now lets grab what matters
            $floor = trim($line2[2]);
            $apartment = trim($line2[4]);
        } else {
            //maybe the user wrote something like "depto. 5, piso 24". Let's try that
            preg_match('/(departamento|depto|dept|dpto|dpt|dpt.º|depto.|dept.|dpto.|dpt.|apartamento|apto|apt|apto.|apt.) ?(\w+),? ?(piso|p|p.) ?(\w+)/i', $fl_apt, $res);
            $line2 = $res;
        }

        if (!empty($line2) && empty($apartment) && empty($floor)) {
            //apparently, that was the case. Guess some people just like to make things difficult
            $floor = trim($line2[4]);
            $apartment = trim($line2[2]);
        } else {
            //something is wrong. Let's be more specific. First we'll try with only the floor
            preg_match('/^(piso|p|p.) ?(\w+)$/i', $fl_apt, $res);
            $line2 = $res;
        }

        if (!empty($line2) && empty($floor)) {
            //now we've got it! The user just wrote the floor number. Now lets grab what matters
            $floor = trim($line2[2]);
        } else {
            //still no. Now we'll try with the apartment
            preg_match('/^(departamento|depto|dept|dpto|dpt|dpt.º|depto.|dept.|dpto.|dpt.|apartamento|apto|apt|apto.|apt.) ?(\w+)$/i', $fl_apt, $res);
            $line2 = $res;
        }

        if (!empty($line2) && empty($apartment) && empty($floor)) {
            //success! The user just wrote the apartment information. No clue why, but who am I to judge
            $apartment = trim($line2[2]);
        } else {
            //ok, weird. Now we'll try a more generic approach just in case the user missplelled something
            preg_match('/(\d+),? [a-zA-Z.,!*]* ?([a-zA-Z0-9 ]+)/i', $fl_apt, $res);
            $line2 = $res;
        }

        if (!empty($line2) && empty($floor) && empty($apartment)) {
            //finally! The user just missplelled something. It happens to the best of us
            $floor = trim($line2[1]);
            $apartment = trim($line2[2]);
        } else {
            //last try! This one is in case the user wrote the floor and apartment together ("12C")
            preg_match('/(\d+)(\D*)/i', $fl_apt, $res);
            $line2 = $res;
        }

        if (!empty($line2) && empty($floor) && empty($apartment)) {
            //ok, we've got it. I was starting to panic
            $floor = trim($line2[1]);
            $apartment = trim($line2[2]);
        } elseif (empty($floor) && empty($apartment)) {
            //I give up. I can't make sense of it. We'll save it in case it's something useful 
            $floor = $fl_apt;
        }

        return array($floor, $apartment);
    }

    /**
     * Devuelve array de datos del producto para enviar e importar en EP
     */
    public function prepareProductForAPI($product_id, $product) 
    {
        $data    = [];
        if ($product) {
           //Obtengo la URL de la imagen del producto
           $imagen_producto = wp_get_attachment_url($product->get_image_id());

           $sku = $product->get_sku();
            if(empty($sku)) {
                $sku = 'WC-'. $product_id;
            }

            $idProducto  = json_decode($product->get_meta('enviopack_product_id'));
            $idsPaquetes = json_decode($product->get_meta('enviopack_product_paquetes'));
            $idPaquete   = null;

            if ($idsPaquetes && isset($idsPaquetes[count($idsPaquetes) - 1])) {
                $idPaquete = $idsPaquetes[count($idsPaquetes) - 1];
            }

            $unidad_peso = get_option('woocommerce_weight_unit');

            $paquetes = [
                [
                    'alto'      => $product->get_height(),
                    'ancho'     => $product->get_width(),
                    'largo'     => $product->get_length(),
                    'peso'      => wc_get_weight($product->get_weight(), 'kg', $unidad_peso),
                    'idPaquete' => $idPaquete
                ]
            ];


            $data['identificadores_alternativos'] = [];
            $data['sku']                          = $sku;
            $data['nombre']                       = $product->get_name();
            $data['imagen']                       = ($imagen_producto) ? $imagen_producto : '';
            $data['plataforma']                   = 'woocommerce';  
            $data['paquetes']                     = $paquetes;
            $data['idProducto']                   = $idProducto;
            $data['valorReposicion']              = $product->get_regular_price();
        }


        return !empty($data) ? $data : false;
    }

    /**
     * Setea un mensaje para ser mostrado en un flash. Las posibles key son: "success", "warning", "error"
     */
    public static function setFlash($key, $mensaje)
    {
        if (session_status() !== PHP_SESSION_ACTIVE) {
            session_start();
        }

        $_SESSION['flashes'][$key][] = $mensaje;
    }

    /**
     * Devulve el html de los flashes para ser impresos
     * 
     * @return array
     */
    public static function getFlashes()
    {
        if (session_status() !== PHP_SESSION_ACTIVE) {
            session_start();
        }

        $flashes = [];

        if (isset($_SESSION['flashes'])) {
            foreach($_SESSION['flashes'] as $type => $flashes) {
                foreach($flashes as $key => $flash) {
                    $flashes[] = "<div id='message' class='notice notice-$type is-dismissible'>
                        <p>$flash</p>
                    </div>";
                    unset($_SESSION['flashes'][$type][$key]);
                }
            }
        }

        return $flashes;
    }

}
